
Session information is not stored server-side
-------

**Description:**

Whenever session information is not stored server-side an attacker could easily tamper 
and manipulate these values. This is always a bad idea and you should not do this!


**Solution:**

Session information should aways be stored server-side by means of a server-side language.

	
